@@ -85,7 +85,7 @@ sub load {
     
     foreach my $module (findsubmod Lim::RPC::Protocol) {
         if (exists $self->{protocol}->{$module}) {
-            Lim::WARN and $self->{logger}->warn('Protocol ', $module, ' already loaded');
+            $self->{logger}->warn('Protocol ', $module, ' already loaded');
             next;
         }
         
@@ -104,7 +104,7 @@ sub load {
         };
         
         if ($@) {
-            Lim::WARN and $self->{logger}->warn('Unable to load protocol ', $module, ': ', $@);
+            $self->{logger}->warn('Unable to load protocol ', $module, ': ', $@);
             $self->{protocol}->{$module} = {
                 module => $module,
                 loaded => 0,
@@ -114,7 +114,7 @@ sub load {
         }
         
         unless ($name =~ /^[a-z0-9_\-\.]+$/o) {
-            Lim::WARN and $self->{logger}->warn('Unable to load protocol ', $module, ': Illegal characters in protocol name');
+            $self->{logger}->warn('Unable to load protocol ', $module, ': Illegal characters in protocol name');
             $self->{protocol}->{$module} = {
                 module => $module,
                 loaded => 0,
@@ -124,11 +124,10 @@ sub load {
         }
 
         if (exists $self->{protocol_name}->{$name}) {
-            Lim::WARN and $self->{logger}->warn('Protocol name ', $name, ' already loaded by module ', $self->{protocol_name}->{$name});
+            $self->{logger}->warn('Protocol name ', $name, ' already loaded by module ', $self->{protocol_name}->{$name});
             next;
         }
         
-        Lim::DEBUG and $self->{logger}->debug('Loaded ', $module);
         $self->{protocol}->{$module} = {
             name => $name,
             module => $module,
@@ -165,7 +164,7 @@ sub protocol {
                 $protocol = $module->new(@_);
             };
             if ($@) {
-                Lim::WARN and $self->{logger}->warn('Unable to create new instance of protocol ', $name, '(', $module, '): ', $@);
+                $self->{logger}->warn('Unable to create new instance of protocol ', $name, '(', $module, '): ', $@);
             }
             else {
                 return $protocol;
